%global python3_pkgversion 39
%global __python3 %{_bindir}/python3.9
%global __pytest /usr/bin/pytest-3.9

Name:		wult
Version:	1.12.16
Release:	1%{?dist}
Summary:	A tool for measuring C-state latency in Linux

License:	BSD-3-Clause
Url:		https://intel.github.io/wult
Source0:	https://github.com/intel/wult/archive/v%{version}/%{name}-%{version}.tar.gz

Patch0:		exclude-dirs.patch

ExclusiveArch:	x86_64

BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	libbpf-devel
BuildRequires:	python%{python3_pkgversion}-devel
BuildRequires:	pepc >= 1.5.5
BuildRequires:	python%{python3_pkgversion}-pluggy
BuildRequires:	python%{python3_pkgversion}-pytest
BuildRequires:	stats-collect >= 1.0.21
BuildRequires:	web-assets-devel
Requires:	pepc >= 1.5.5
Requires:	pciutils
Requires:	python%{python3_pkgversion}-wult
Requires:	stats-collect >= 1.0.21
Requires:	web-assets-filesystem

%description
The name Wult comes from "Wake Up Latency Tracer". Wult measures C-state
latency by scheduling a delayed interrupt at a known time in the future, so it
relies on devices allowing for delayed interrupts. Today wult can use LAPIC as
the source of delayed interrupts, as well as I210 PCIe Gigabit Ethernet
adapter. However, other devices could be supported as well, for example other
Intel Ethernet adapters.

%package -n python%{python3_pkgversion}-%{name}
Summary: Wult Python library
BuildArch:	noarch

%description -n python%{python3_pkgversion}-%{name}
Wult Python library

%prep
%autosetup -p1 -n %{name}-%{version}

# only for c8s
for f in wult ndl
do
  sed -i '1 s/python3/python3.9/' $f
done 

%build
%py3_build

# Use default C and linker flags
export CFLAGS="%optflags"
export LDFLAGS="%{__global_ldflags}"
%make_build -C helpers/ndl-helper
%make_build -C helpers/wult-hrt-helper
%make_build -C helpers/wult-tdt-helper

%install
%py3_install
install -pDm755 helpers/ndl-helper/ndl-helper %{buildroot}%{_bindir}/ndl-helper
install -pDm755 helpers/wult-hrt-helper/wult-hrt-helper %{buildroot}%{_bindir}/wult-hrt-helper
install -pDm755 helpers/wult-tdt-helper/wult-tdt-helper %{buildroot}%{_bindir}/wult-tdt-helper

%check
%pytest -v

%files
%doc README.md CHANGELOG.md
%license LICENSE.md
%{_bindir}/exercise-sut
%{_bindir}/ndl
%{_bindir}/ndl-helper
%{_bindir}/wult
%{_bindir}/wult-hrt-helper
%{_bindir}/wult-tdt-helper
%{_datadir}/wult
%{_mandir}/man1/exercise-sut.1*
%{_mandir}/man1/ndl.1*
%{_mandir}/man1/wult.1*

%files -n python%{python3_pkgversion}-%{name}
%{python3_sitelib}/wultlibs
%{python3_sitelib}/wulttools
%{python3_sitelib}/wult-*.egg-info/

%changelog
* Mon Feb 19 2024 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.12.16-1
- Update to 1.12.16

* Mon Aug 28 2023 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.12.9-1
- Update to 1.12.9

* Thu Jun 29 2023 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.12.2-1
- Update to 1.12.2

* Tue May 09 2023 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.11.16-1
- Update to 1.11.16

* Mon May 08 2023 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.11.15-1
- Update to 1.11.15

* Wed Jan 18 2023 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.54-1
- Update to 1.10.54

* Thu Nov 24 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.40-1
- Update to 1.10.40

* Wed Oct 19 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.34-1
- Update to 1.10.34

* Thu Sep 22 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.31-1
- Update to 1.10.31

* Wed Sep 07 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.27-1
- Update to 1.10.27

* Tue Sep 06 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.26-1
- Update to 1.10.26

* Wed Aug 31 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.25-1
- Update to 1.10.25

* Mon Aug 29 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.23-2
- Wultrunner binary fix

* Mon Aug 29 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.23-1
- Update to 1.10.23

* Thu Aug 25 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.22-1
- Update to 1.10.22

* Mon Aug 01 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.12-1
- Update to 1.10.12

* Thu Jul 21 2022 Ali Erdinc Koroglku <aekoroglu@centosproject.org> - 1.10.11-1
- Update to 1.10.11

* Thu Jul 07 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.9-1
- Update to 1.10.9

* Mon Jul 04 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.8-1
- Update to 1.10.8

* Tue Jun 28 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.7-1
- Update to 1.10.7

* Sat Jun 25 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.6-1
- Update to 1.10.6

* Tue Jun 21 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.5-3
- Pyyaml typo fix and dwarves dependency

* Mon Jun 20 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.5-2
- Deploy.py helpers typo fix

* Sun Jun 19 2022 Ali Erdinc Koroglu <aekoroglu@centosproject.org> - 1.10.5-1
- Initial package
